function [ WT ] = phasewt ( DWT, DIST, RES, ITER, PHASE, NDAT, USEPHASE )

% function [ WT ] = phasewt ( DWT, DIST, RES, ITER, PHASE )
% Input:
% WT       phase weight
% Output:
% DWT      User assigned weight 0-4 maps into 1 ->0.0
% DIST     Distance
% RES      Residual
% ITER     Iteration
% PHASE    downweight everything not a P
% NDAT     number of phases
% USEPHASE  = use the phase, 0 = do not usethe phase

xnear = 50 ;
xfar = 500 ;
tres = 1.0 ;

        % convert weights in range [0,4) to [ 1.0, 0 ];
        ONE=ones(NDAT,1);
        WT= ( 4*ONE - DWT)/4.;

	if ( ITER > 3 )
		%	distance weighting applied after 3 iterations
		for ( i =1:NDAT)
			if (DIST(i) > xnear )
				% this weight is 1 at xnear and 0.1 at xfar
				WT(i) *= (xfar-xnear)/(9*DIST(1)+xfar-10*xnear) ;
			end
		end
		% simple residual weighting
		for ( i =1:NDAT)
				% this weight is 1 at xnear and 0.1 at xfar
			WT(i) *=  tres / (tres+abs(RES(i)*RES(i))) ;
		end
		
		
	end

% final check
for ( i =1:NDAT)
	if !USEPHASE(i)
		WT(i) = 0 ;
	end
	if (!strcmp(PHASE(i),'P') )
		WT(i)/=2. ;
	end
end
WT=sqrt(WT);

endfunction
